package Gear::Remotes::Entry;

use strict;
use warnings;

sub new {
    my $proto=shift;
    my $class=ref($proto) || $proto;
    my $self = {
	-remotename => 'upstream',
	-url => undef,
	@_,
    };
    my $url=$self->{-url};
    die "Gear::Remotes::Entry: new needs an url.\n" if not $url;
    $self->{-url}=&_trim_url($url);
    bless($self,$class);
    return $self;
}

sub label {
    my $self=shift;
    my $label=$self->{-label};
    return $label if defined $label;
    return $self->{-remotename}.'='.$self->{-url};
}

sub list {
    my $self=shift;
    return ('remote.'.$self->{-remotename}.'.fetch=+refs/heads/*:refs/remotes/'.$self->{-remotename}.'/*',
	    'remote.'.$self->{-remotename}.'.url='.$self->{-url});

}

sub append {
    my ($self, $to)=@_;
    open (my $fh, '>>', $to) || die 'write to ',$to, ' failed: ',$!;
    print $fh $self->config_entry();
    close ($fh) || die 'close ',$to, ' failed: ',$!;
}

sub config_entry {
    my $self=shift;
    return '[remote "'.$self->{-remotename}.'"]
        fetch = +refs/heads/*:refs/remotes/'.$self->{-remotename}.'/*
        url = '.$self->{-url}."\n";
}

sub _trim_url {
    my $url=shift;
    # force https:// for security
    $url =~s!^http:/!https:/!;
    $url =~s!^git+https?:/!https:/!;
    # use git+https:// instead of ftp or rsync for gitlab and github
    $url =~s!^(?:ftp|rsync)(://git(?:hub|lab)\.com/)!https$1!;
    return $url;
}


1;

__END__
